import pytest
from aiohttp import ClientSession
from yarl import URL

from resa_padel.gestion_sports_connector import GestionSportsConnector

gestion_sports_url = "https://toulousepadelclub.gestion-sports.com"
test_user = "padel.testing@jouf.fr"
test_user_id = "232382"
test_password = "ridicule"
test_club_id = "88"


@pytest.mark.asyncio
async def test_should_connect_to_gestion_sports_website():
    async with ClientSession() as session:
        cookies = session.cookie_jar.filter_cookies(URL(gestion_sports_url))
        assert cookies.get("PHPSESSID") is None
        gs_connector = GestionSportsConnector(session, gestion_sports_url)

        response = await gs_connector.connect()

        assert response.status == 200
        assert response.request_info.method == "GET"
        assert response.content_type == "text/html"
        assert response.request_info.url == URL(gestion_sports_url + "/connexion.php")
        assert response.charset == "UTF-8"

        cookies = session.cookie_jar.filter_cookies(URL(gestion_sports_url))
        assert cookies.get("PHPSESSID") is not None


@pytest.mark.asyncio
async def test_should_login_to_gestion_sports_website():
    async with ClientSession() as session:
        gs_connector = GestionSportsConnector(session, gestion_sports_url)
        await gs_connector.connect()

        response = await gs_connector.login(test_user, test_password, test_club_id)

        assert response.status == 200
        assert response.request_info.url == URL(gestion_sports_url + "/connexion.php")
        assert response.request_info.method == "POST"

        cookies = session.cookie_jar.filter_cookies(URL(gestion_sports_url))
        assert cookies.get("COOK_ID_CLUB").value == test_club_id
        assert cookies.get("COOK_ID_USER").value == test_user_id
        assert cookies.get("PHPSESSID") is not None
